@@ -5,8 +5,8 @@ from bpkio_api.models.Sources import SourceType
 
 class SourceTypeDetector:
     @staticmethod
-    def determine_source_type(url) -> SourceType:
-        handler = handlers.factory.create_handler(url)
+    def determine_source_type(url, headers=None) -> SourceType:
+        handler = handlers.factory.create_handler(url, explicit_headers=headers)
 
         match handler:
             case handlers.HLSHandler() | handlers.DASHHandler():
