@@ -2,7 +2,7 @@ from enum import Enum
 from typing import List, Literal, Optional
 from urllib.parse import urljoin
 
-from bpkio_api.models.MediaFormat import MediaFormat
+from media_muncher.format import MediaFormat
 from pydantic import AnyHttpUrl, BaseModel, IPvAnyAddress
 
 from .common import BaseResource, NamedModel, PropertyMixin, WithDescription
