@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import Optional
 
-from bpkio_api.models.common import BaseModel, NamedModel
+from bpkio_api.models.common import NamedModel
 from pydantic import PrivateAttr
 
 
@@ -16,5 +16,7 @@ class Tenant(NamedModel):
     sendAnalytics: Optional[bool] = False
     creationDate: datetime
     updateDate: datetime
+    subscriptionDate: Optional[datetime]
+    expirationDate: Optional[datetime]
 
     _fqdn: str = PrivateAttr()
